<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="442"/>
        <location filename="../../CopyEngine.cpp" line="465"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>엔진이 강제로 이동합니다. 사용자가 복사할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="519"/>
        <location filename="../../CopyEngine.cpp" line="542"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>엔진이 강제로 복사합니다. 사용자가 이동할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Destination</source>
        <translation type="unfinished">대상</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation type="unfinished">실제 대상 &quot;%1&quot;를(을) 사용하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="731"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>모드가 이전에 강제되었습니다. 내부 오류입니다. 문제를 보고해 주세요.</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="886"/>
        <source>Supported only on Windows</source>
        <translation type="unfinished">Windows에서만 지원</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1035"/>
        <location filename="../../CopyEngine.cpp" line="1038"/>
        <location filename="../../CopyEngine.cpp" line="1043"/>
        <location filename="../../CopyEngine.cpp" line="1047"/>
        <source>Ask</source>
        <translation type="unfinished">확인</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1036"/>
        <location filename="../../CopyEngine.cpp" line="1040"/>
        <location filename="../../CopyEngine.cpp" line="1044"/>
        <location filename="../../CopyEngine.cpp" line="1048"/>
        <source>Skip</source>
        <translation type="unfinished">건너뛰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1039"/>
        <source>Merge</source>
        <translation type="unfinished">합치기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1041"/>
        <location filename="../../CopyEngine.cpp" line="1053"/>
        <source>Rename</source>
        <translation type="unfinished">이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1045"/>
        <source>Put at the end</source>
        <translation type="unfinished">끝에 놓기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1049"/>
        <source>Overwrite</source>
        <translation type="unfinished">덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1050"/>
        <source>Overwrite if different</source>
        <translation type="unfinished">다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1051"/>
        <source>Overwrite if newer</source>
        <translation type="unfinished">더 최신이면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1052"/>
        <source>Overwrite if older</source>
        <translation type="unfinished">더 이전이면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options error</source>
        <translation type="unfinished">옵션 오류</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>옵션 엔진이 호출되지 않았습니다. 필터에 액세스할 수 없습니다. </translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="60"/>
        <location filename="../../CopyEngineFactory.cpp" line="309"/>
        <source>Supported only on Windows</source>
        <translation type="unfinished">Windows에서만 지원</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Ask</source>
        <translation type="unfinished">확인</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Skip</source>
        <translation type="unfinished">건너뛰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Merge</source>
        <translation type="unfinished">합치기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <location filename="../../CopyEngineFactory.cpp" line="454"/>
        <source>Rename</source>
        <translation type="unfinished">이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="446"/>
        <source>Put at the end</source>
        <translation type="unfinished">끝에 놓기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="450"/>
        <source>Overwrite</source>
        <translation type="unfinished">덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="451"/>
        <source>Overwrite if different</source>
        <translation type="unfinished">다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="452"/>
        <source>Overwrite if newer</source>
        <translation type="unfinished">더 최신이면 덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="453"/>
        <source>Overwrite if older</source>
        <translation type="unfinished">더 이전이면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options error</source>
        <translation type="unfinished">옵션 오류</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>옵션 엔진이 호출되지 않았습니다. 필터에 액세스할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>옵션 엔진이 호출되지 않았습니다. 필터에 액세스할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation type="unfinished">디스크 공간</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>이 전송을 완료하려면 이 드라이브에 더 많은 공간이 있어야 합니다.</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation type="unfinished">계속</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation type="unfinished">%1 드라이브에서 %2 사용 가능, 하지만 %3 필요함</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="92"/>
        <source>Error on folder</source>
        <translation type="unfinished">폴더 오류</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="95"/>
        <source>Folder name</source>
        <translation type="unfinished">폴더 이름</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="201"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished">%name% - 복사%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="208"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished">%name% - 복사 (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Error</source>
        <translation type="unfinished">오류</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Try rename with using special characters</source>
        <translation>특수 문자를 사용하여 이름을 바꾸세요.</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="145"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished">%name% - 복사%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="152"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished">%name% - 복사 (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Error</source>
        <translation type="unfinished">오류</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Try rename with using special characters</source>
        <translation>특수 문자를 사용하여 이름을 바꾸세요.</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation type="unfinished">필터 대화 상자</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation type="unfinished">검색:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation type="unfinished">검색 유형:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation type="unfinished">원시 텍스트</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation type="unfinished">단순 정규식</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation type="unfinished">Perl 정규식</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation type="unfinished">적용 대상:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation type="unfinished">파일</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation type="unfinished">폴더</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation type="unfinished">파일 및 폴더</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation type="unfinished">전체 문자열 일치</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation type="unfinished">테스트 문자열 정규식과 일치</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation type="unfinished">검사</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation type="unfinished">정규식 유효성 검사</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation type="unfinished">테스트 문자열:</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation type="unfinished">필터</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="39"/>
        <source>Exclusion filters</source>
        <translation type="unfinished">제외 필터</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="111"/>
        <source>Inclusion filters</source>
        <translation type="unfinished">포함 필터</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="132"/>
        <source>None = Include all</source>
        <translation type="unfinished">없음 = 모두 포함</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="94"/>
        <location filename="../../Filters.cpp" line="132"/>
        <source>Raw text</source>
        <translation type="unfinished">원시 텍스트</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="97"/>
        <location filename="../../Filters.cpp" line="135"/>
        <source>Simplified regex</source>
        <translation type="unfinished">단순 정규식</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="100"/>
        <location filename="../../Filters.cpp" line="138"/>
        <source>Perl&apos;s regex</source>
        <translation type="unfinished">Perl 정규식</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="108"/>
        <location filename="../../Filters.cpp" line="146"/>
        <source>Only on file</source>
        <translation type="unfinished">파일에서만</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="111"/>
        <location filename="../../Filters.cpp" line="149"/>
        <source>Only on folder</source>
        <translation type="unfinished">폴더에서만</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="117"/>
        <location filename="../../Filters.cpp" line="155"/>
        <location filename="../../Filters.cpp" line="217"/>
        <location filename="../../Filters.cpp" line="256"/>
        <source>Full match</source>
        <translation type="unfinished">전체 일치</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="91"/>
        <source>Folder already exists</source>
        <translation>폴더가 이미 존재합니다.</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="172"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished">%name% - 복사%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="181"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished">%name% - 복사 (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Try rename with using special characters</source>
        <translation>특수 문자를 사용하여 이름을 바꾸세요.</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="242"/>
        <location filename="../../ListThreadListChange.cpp" line="413"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation type="unfinished">잘못된 강제 모드로 항목을 이동하거나 복사할 수 없음: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="249"/>
        <location filename="../../ListThreadListChange.cpp" line="420"/>
        <source>Unable to save the transfer list: %1</source>
        <translation type="unfinished">전송 목록을 저장할 수 없음: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="270"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>파일 읽기 문제 또는 파일 크기가 0입니다.</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="277"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation type="unfinished">잘못된 헤더: &quot;%1&quot; </translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="286"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>전송 목록이 혼합 모드에 있지만 이 인스턴스가 혼합 모드에 있지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="295"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>전송 목록이 복사 모드에 있지만 이 인스턴스가 복사 모드에 있지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="301"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>전송 목록이 이동 모드에 있지만 이 인스턴스가 이동 모드에 있지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="365"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>라인 구문 분석 중 어떤 오류가 발견되었습니다.</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="373"/>
        <source>Unable to open the transfer list: %1</source>
        <translation type="unfinished">전송 목록을 열 수 없음: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="187"/>
        <location filename="../../MkPath.cpp" line="210"/>
        <location filename="../../MkPath.cpp" line="315"/>
        <location filename="../../MkPath.cpp" line="363"/>
        <source>Unable to create the folder</source>
        <translation type="unfinished">폴더를 만들 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="227"/>
        <source>The source folder don&apos;t exists</source>
        <translation>원본 폴더가 존재하지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="304"/>
        <source>Unable to temporary rename the folder</source>
        <translation>폴더 이름을 임시로 바꿀 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="339"/>
        <source>Unable to reverse temporary rename for real move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="348"/>
        <source>Unable to do the final real move the folder</source>
        <translation>폴더를 이동할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="379"/>
        <source>Unable to move the folder</source>
        <translation>폴더를 이동할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="385"/>
        <source>Unable to move the folder: errno: %1</source>
        <translation type="unfinished">폴더를 이동할 수 없습니다. Errno: %1 </translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="124"/>
        <location filename="../../MkPath.cpp" line="464"/>
        <source>Unable to remove</source>
        <translation>제거할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../async/ReadThread.cpp" line="78"/>
        <source>Internal error, please report it!</source>
        <translation type="unfinished">내부 오류. 이 문제를 보고해 주세요!</translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="543"/>
        <source>Unable to read the source file: </source>
        <translation type="unfinished">원본 파일을 읽을 수 없습니다: </translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="599"/>
        <source>File truncated during the read, possible data change</source>
        <translation>읽기 중 파일이 잘림. 데이터가 변경되었을 수 있습니다. </translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation type="unfinished">이름 바꾸기 규칙</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation type="unfinished">첫 번째 이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation type="unfinished">%name% - 복사%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished">%name% - 복사 (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;변수: 원본 파일명은 &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt;, 숫자는 &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt;, 파일 접미사는 &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation type="unfinished">두 번째 이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="46"/>
        <location filename="../../RenamingRules.cpp" line="71"/>
        <source>%1 - copy%2</source>
        <translation type="unfinished">%1 - 복사%2</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="50"/>
        <location filename="../../RenamingRules.cpp" line="84"/>
        <source>%1 - copy (%2)%3</source>
        <translation type="unfinished">%1 - 복사 (%2)%3</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="331"/>
        <location filename="../../ScanFileOrFolder.cpp" line="681"/>
        <source>Blacklisted folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="463"/>
        <location filename="../../ScanFileOrFolder.cpp" line="465"/>
        <source>%1 - copy</source>
        <translation type="unfinished">%1 - 복사</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="474"/>
        <location filename="../../ScanFileOrFolder.cpp" line="476"/>
        <source>%1 - copy (%2)</source>
        <translation type="unfinished">%1 - 복사 (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - 복사</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="598"/>
        <location filename="../../ScanFileOrFolder.cpp" line="600"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - 복사 (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="691"/>
        <location filename="../../ScanFileOrFolder.cpp" line="695"/>
        <source>Problem with folder read</source>
        <translation type="unfinished">폴더 읽기 문제</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="628"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished">%name% - 복사%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="635"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished">%name% - 복사 (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="663"/>
        <location filename="../../TransferThread.cpp" line="904"/>
        <source>File not found</source>
        <translation>파일을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="904"/>
        <location filename="../../TransferThread.cpp" line="940"/>
        <source>Unable to change the date</source>
        <translation>날짜를 변경할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="188"/>
        <source>Try rename with using special characters</source>
        <translation>특수 문자를 사용하여 이름을 바꾸세요.</translation>
    </message>
</context>
<context>
    <name>TransferThreadAsync</name>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="342"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation>수정 날짜가 잘못되었거나 가져올 수 없습니다. 시간 보내기를 비활성화할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="436"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="454"/>
        <source>Unable to create the destination folder: </source>
        <translation type="unfinished">대상 폴더를 만들 수 없음:</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="439"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="456"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation type="unfinished">대상 폴더를 만들 수 없음. Errno: %1</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../async/WriteThread.cpp" line="138"/>
        <source>Path resolution error (Empty path)</source>
        <translation type="unfinished">경로 확인 오류 (빈 경로)</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="167"/>
        <location filename="../../async/WriteThread.cpp" line="200"/>
        <source>Unable to create the destination folder: </source>
        <translation type="unfinished">대상 폴더를 만들 수 없음:</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="178"/>
        <location filename="../../async/WriteThread.cpp" line="202"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation type="unfinished">대상 폴더를 만들 수 없음. Errno: %1</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="464"/>
        <source>Internal error, please report it!</source>
        <translation type="unfinished">내부 오류. 문제를 보고해 주세요!</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation type="unfinished">보내기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="63"/>
        <source>Move the whole folder</source>
        <translation type="unfinished">전체 폴더 이동</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="97"/>
        <source>Transfer the file rights</source>
        <translation type="unfinished">파일 권한 전송</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="76"/>
        <source>Keep the file date</source>
        <translation type="unfinished">파일 날짜 유지</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="114"/>
        <source>Create full path if not exists</source>
        <translation type="unfinished">존재하지 않으면 전체 경로 만들기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="138"/>
        <source>Checksum</source>
        <translation type="unfinished">체크섬</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Auto start</source>
        <translation type="unfinished">자동 시작</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="154"/>
        <source>Error and collision</source>
        <translation type="unfinished">오류 및 충돌 </translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="160"/>
        <source>When folder error</source>
        <translation type="unfinished">폴더 오류 시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="170"/>
        <source>When file error</source>
        <translation type="unfinished">파일 오류 시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="196"/>
        <source>When file collision</source>
        <translation type="unfinished">파일 충돌 시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="239"/>
        <source>Overwrite if not same size</source>
        <translation type="unfinished">크기가 다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="244"/>
        <source>Overwrite if modification date differs</source>
        <translation type="unfinished">수정한 날짜가 다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="266"/>
        <source>When folder collision</source>
        <translation type="unfinished">폴더 충돌 시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="297"/>
        <source>Check if destination folder exists</source>
        <translation type="unfinished">대상 폴더가 있는지 확인</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="304"/>
        <source>Renaming rules</source>
        <translation type="unfinished">이름 바꾸기 규칙</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="324"/>
        <source>Delete partially transferred files</source>
        <translation type="unfinished">부분적으로 전송된 파일 삭제</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="337"/>
        <source>Rename the original destination</source>
        <translation type="unfinished">원래 대상 이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="368"/>
        <source>Performance</source>
        <translation type="unfinished">성능</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="387"/>
        <source>Inode threads</source>
        <translation type="unfinished">아이노드(Inode) 스레드</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="397"/>
        <location filename="../../copyEngineOptions.ui" line="413"/>
        <source>MB</source>
        <translation type="unfinished">MB</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="429"/>
        <source>Uncheck this under Windows create problem</source>
        <translation>Windows에 문제가 있을 경우 이것을 체크 해제하세요.</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="436"/>
        <source>OS Buffer</source>
        <translation type="unfinished">OS 버퍼</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="456"/>
        <source>Disable parallel transfer when are different devices</source>
        <translation type="unfinished">다른 장치 일 때 병렬 전송 비활성화</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="463"/>
        <source>Buffer for different device</source>
        <translation type="unfinished">다른 장치에 대한 버퍼</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="470"/>
        <source>OS FLags</source>
        <translation type="unfinished">OS FLags</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="477"/>
        <source>Buffer for same device</source>
        <translation type="unfinished">같은 장치에 대한 버퍼</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="484"/>
        <source>OS native copy (disable speed limitation)</source>
        <translation type="unfinished">OS 기본 복사 (속도 제한 사용 안 함)</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="514"/>
        <source>Misc</source>
        <translation type="unfinished">기타</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="520"/>
        <source>Check the disk space</source>
        <translation type="unfinished">디스크 공간 확인</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="530"/>
        <source>Use this folder when destination is not set</source>
        <translation type="unfinished">대상이 설정되지 않은 경우 이 폴더 사용</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="542"/>
        <source>Browse</source>
        <translation type="unfinished">찾아보기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="564"/>
        <source>Filters</source>
        <translation type="unfinished">필터</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation type="unfinished">파일 오류</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation type="unfinished">수정한 날짜</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation type="unfinished">대상</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation type="unfinished">폴더</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished">&amp;항상 이 동작 수행</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation type="unfinished">높은 권한으로 시도</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>아래에 놓기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>재시도</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>파일이 존재합니다</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>대상</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation type="unfinished">수정한 날짜</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation type="unfinished">폴더</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished">&amp;항상 이 동작 수행</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if source newer than destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation type="unfinished">수정한 날짜가 다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <source>Overwrite if source older than destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if destination older</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="362"/>
        <location filename="../../fileExistsDialog.ui" line="365"/>
        <source>Overwrite if not same size</source>
        <translation type="unfinished">크기가 다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="370"/>
        <location filename="../../fileExistsDialog.ui" line="373"/>
        <source>Overwrite if not same size and date</source>
        <translation type="unfinished">크기와 날짜가 다르면 덮어쓰기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation type="unfinished">수정한 날짜</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation type="unfinished">원본과 대상이 동일함</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation type="unfinished">폴더</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished">&amp;항상 이 동작 수행</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>대상</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation type="unfinished">원본과 대상이 동일함</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation type="unfinished">수정한 날짜</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>폴더 이름</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation type="unfinished">폴더</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished">&amp;항상 이 동작 수행</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>합치기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>건너뛰기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
</TS>
